import { Component } from '@angular/core';
import { JBUtilMobileNumberModel } from '@justbe-utilities/mobile-number';
import { AlertController } from 'ionic-angular';
import { StoreService } from '@justbe-angular/jb-store';
import { RestService } from '../../services/rest-service';
import { AuthService } from '@justbe-ionic-angular/auth-data-handler';
var mobile_number_form_tpl = "\n<ion-list no-margin>\n  <ion-item padding-left padding-right>\n    <ion-label>Country</ion-label>\n    <ion-select [(ngModel)]=\"jbMobileAuthJson.countryCode\">\n      <ion-option [value]=\"country\" multiple=\"false\" *ngFor=\"let country of jbMobileAuthJson.countries\">{{country?.name}}</ion-option>\n    </ion-select>\n  </ion-item>\n  <ion-item padding-left padding-right>\n    <ion-label floating>Mobile No</ion-label>\n    {{jbMobileAuthJson?.countryCode?.tel}}\n    <ion-input (keyup.enter)=\"sendOtp()\" [(ngModel)]=\"jbMobileAuthJson.mobileNumber\" type=\"number\" (ngModelChange)=\"mobileChanged($event)\"></ion-input>\n  </ion-item>\n  <ion-item padding style=\"font-size: 0.9em;color: red;\" *ngIf=\"errorMsg\">\n    {{errorMsg}}\n  </ion-item>\n  <ion-item text-center>\n    <ion-buttons>\n      <button ion-button color=\"primary\" *ngIf=\"sendingOTP\" round>\n        <ion-spinner name=\"bubbles\" color=\"light\" item-end></ion-spinner>\n      </button>\n      <button ion-button [disabled]=\"!jbMobileAuthJson.isMobileNumberValid\" (click)=\"sendOtp()\" *ngIf=\"!sendingOTP\" color=\"primary\" round>Get OTP</button>\n    </ion-buttons>\n  </ion-item>\n</ion-list>\n";
var mobile_number_form_css = " ";
var MobileNumberFormComponent = (function () {
    function MobileNumberFormComponent(alertCtrl, storeService, restService, authService) {
        this.alertCtrl = alertCtrl;
        this.storeService = storeService;
        this.restService = restService;
        this.authService = authService;
    }
    MobileNumberFormComponent.prototype.ngOnInit = function () {
        this.jbMobileAuthJson = this.storeService.getSubstore('jb-mobile-auth-json');
        this.jbMobileAuthJson.countryCode = this.jbMobileAuthJson.countries[0];
    };
    MobileNumberFormComponent.prototype.mobileChanged = function (mobileNumber) {
        this.jbMobileAuthJson.isMobileNumberValid = JBUtilMobileNumberModel.validate(mobileNumber);
        this.errorMsg = '';
    };
    MobileNumberFormComponent.prototype.sendOtp = function () {
        this.presentConfirm();
    };
    MobileNumberFormComponent.prototype.continueSendingOtp = function () {
        var _this = this;
        this.sendingOTP = true;
        if (this.isTestLogin(this.jbMobileAuthJson.mobileNumber)) {
            this.authService.setConfigs({
                api: this.getTestDataApi()
            });
        }
        this.restService.getOtp(this.jbMobileAuthJson).subscribe(function (res) {
            if (res.id) {
                _this.jbMobileAuthJson["isMobileNumberForm"] = false;
                _this.jbMobileAuthJson["isOtpSubmitForm"] = true;
            }
            else {
                _this.errorMsg = 'Error sending OTP';
            }
            _this.sendingOTP = false;
        });
    };
    MobileNumberFormComponent.prototype.presentConfirm = function () {
        var _this = this;
        var alert = this.alertCtrl.create({
            title: this.jbMobileAuthJson.countryCode.tel + " " + this.jbMobileAuthJson.mobileNumber,
            message: "Is your phone number correct?",
            buttons: [
                {
                    text: 'Edit',
                    role: 'cancel',
                    handler: function () {
                    }
                },
                {
                    text: 'Yes',
                    handler: function () {
                        _this.continueSendingOtp();
                    }
                }
            ]
        });
        alert.present();
    };
    MobileNumberFormComponent.prototype.isTestLogin = function (usermobileNumber) {
        var result = false;
        var testData = this.getTestData();
        if (testData) {
            var mobile = testData.iosTestMobileNumber;
            if (mobile === usermobileNumber) {
                result = true;
            }
        }
        return result;
    };
    MobileNumberFormComponent.prototype.getTestData = function () {
        var testData;
        var loginOptions = this.storeService.getSubstore('loginOptions');
        if (loginOptions && loginOptions.testData) {
            testData = loginOptions.testData;
        }
        return testData;
    };
    MobileNumberFormComponent.prototype.getTestDataApi = function () {
        var testData = this.getTestData();
        return testData.testApi;
    };
    MobileNumberFormComponent.decorators = [
        { type: Component, args: [{
                    selector: 'mobile-number-form',
                    template: mobile_number_form_tpl,
                    styles: [mobile_number_form_css]
                },] },
    ];
    /** @nocollapse */
    MobileNumberFormComponent.ctorParameters = function () { return [
        { type: AlertController, },
        { type: StoreService, },
        { type: RestService, },
        { type: AuthService, },
    ]; };
    return MobileNumberFormComponent;
}());
export { MobileNumberFormComponent };
//# sourceMappingURL=mobile-number-form.component.js.map